@@ -1,8 +1,6 @@
-package UV::Async;
+package UV::Async 2.001;
 
-our $VERSION = '2.000';
-
-use strict;
+use v5.14;
 use warnings;
 use parent 'UV::Handle';
 
@@ -20,8 +18,10 @@ UV::Async - Async notification handles in libuv
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
   #!/usr/bin/env perl
-  use strict;
+  use v5.14;
   use warnings;
 
   use UV;
