@@ -1,8 +1,6 @@
-package UV::Idle;
+package UV::Idle 2.001;
 
-our $VERSION = '2.000';
-
-use strict;
+use v5.14;
 use warnings;
 use parent 'UV::Handle';
 
@@ -38,8 +36,10 @@ UV::Idle - Idle handles in libuv
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
   #!/usr/bin/env perl
-  use strict;
+  use v5.14;
   use warnings;
 
   use UV;
