@@ -1,8 +1,6 @@
-package UV::Loop;
+package UV::Loop 2.001;
 
-our $VERSION = '2.000';
-
-use strict;
+use v5.14;
 use warnings;
 
 use Carp ();
@@ -75,8 +73,10 @@ UV::Loop - Looping with libuv
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
   #!/usr/bin/env perl
-  use strict;
+  use v5.14;
   use warnings;
 
   use UV::Loop ();
@@ -330,7 +330,7 @@ C<AI_CANONNAME> flag was included in the request.
 
 =head2 getnameinfo
 
-    $req = $loop->getnameinfo($addr, $flags, $callback)
+    $req = $loop->getnameinfo($addr, $flags, $callback);
 
         $callback->($status, $hostname, $service)
 
