@@ -1,12 +1,11 @@
-package UV::Process;
+package UV::Process 2.001;
 
-our $VERSION = '2.000';
-
-use strict;
+use v5.14;
 use warnings;
-use Carp ();
 use parent 'UV::Handle';
 
+use Carp ();
+
 sub spawn {
     my $self = shift;
     ref $self or $self = $self->new(@_);
@@ -32,8 +31,10 @@ UV::Process - Process handles in libuv
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
   #!/usr/bin/env perl
-  use strict;
+  use v5.14;
   use warnings;
 
   use UV;
