@@ -1,12 +1,11 @@
-package UV::Stream;
+package UV::Stream 2.001;
 
-our $VERSION = '2.000';
-
-use strict;
+use v5.14;
 use warnings;
-use Carp ();
 use parent 'UV::Handle';
 
+use Carp ();
+
 sub listen
 {
     my $self = shift;
@@ -39,8 +38,10 @@ UV::Stream - Stream handles in libuv
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
   #!/usr/bin/env perl
-  use strict;
+  use v5.14;
   use warnings;
 
   use UV;
