@@ -1,12 +1,11 @@
-package UV::Timer;
+package UV::Timer 2.001;
 
-our $VERSION = '2.000';
-
-use strict;
+use v5.14;
 use warnings;
+use parent 'UV::Handle';
+
 use Carp ();
 use Exporter qw(import);
-use parent 'UV::Handle';
 
 our @EXPORT_OK = (@UV::Timer::EXPORT_XS,);
 
@@ -49,8 +48,10 @@ UV::Timer - Timers in libuv
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
   #!/usr/bin/env perl
-  use strict;
+  use v5.14;
   use warnings;
 
   use UV;
