@@ -1,12 +1,11 @@
-package UV::UDP;
+package UV::UDP 2.001;
 
-our $VERSION = '2.000';
-
-use strict;
+use v5.14;
 use warnings;
+use parent 'UV::Handle';
+
 use Carp ();
 use Exporter qw(import);
-use parent 'UV::Handle';
 
 our @EXPORT_OK = (@UV::UDP::EXPORT_XS,);
 
@@ -29,8 +28,10 @@ UV::UDP - UDP socket handles in libuv
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
     #!/usr/bin/perl
-    use strict;
+    use v5.14;
     use warnings;
 
     use Socket;
